Learn R Programming

ConformalSmallest (version 1.0)

pois_n400_reps100: Outcomes of an example for tuning-free conformalized quantile regression(CQR).

Description

A dataset containing the experiment results used in the vignettes.

Usage

pois_n400_reps100

Arguments

Format

A list with 10 elements: x_test, n,nrep,width_mat, cov_mat,beta_mat, ntree_mat, cqr_method_mat, evaluations, alpha

x_test

test points of x

n

number of training samples

nrep

number of replications

width_mat

a data frame with the first column being the width of the prediction regions

cov_mat

a data frame with the first column being the coverage of the prediction regions

beta_mat

a data frame with the first column being the beta for CQR used in the final prediction

ntree_mat

a data frame with the first column being the number of trees for CQR used in the final prediction

ntree_mat

a data frame with the first column being the CQR method (among CQR, CQR-m, CQR-r)used in the final prediction

alpha

desired miscoverage level