Learn R Programming

ConformalSmallest (version 1.0)

ridge_linear_cov100_t3: Outcomes of an example for tuning-free conformal prediction with ridge regression.

Description

A dataset containing the experiment results used in the vignettes.

Usage

ridge_linear_cov100_t3

Arguments

Format

A list with 7 elements: dim_linear_t3,cov.param_linear_fm_t3, cov.naive_linear_fm_t3, cov.vfcp_linear_fm_t3, cov.star_linear_fm_t3, cov.cv5_linear_fm_t3, cov.efcp_linear_fm_t3

dim

dimensions used in the experiment

len.param

a matrix with coverages for the prediction regions produced by the parametric method

len.naive

a matrix with coverages for the prediction regions produced by naive linear regression method

len.vfcp

na matrix with coverages for the prediction regions produced by VFCP

len.star

a matrix with coverages for the prediction regions produced by cross validation with the errors

len.cv5

a matrix with coverages for the prediction regions produced by cross-validation with 5 splits

len.efcp

a matrix with coverages for the prediction regions produced by efcp