Learn R Programming

ConformalSmallest (version 1.0)

ridge_linear_cov100_t5: Outcomes of an example for tuning-free conformal prediction with ridge regression.

Description

A dataset containing the experiment results used in the vignettes.

Usage

ridge_linear_cov100_t5

Arguments

Format

A list with 7 elements: dim_linear_t5,cov.param_linear_fm_t5, cov.naive_linear_fm_t5, cov.vfcp_linear_fm_t5, cov.star_linear_fm_t5, cov.cv5_linear_fm_t5, cov.efcp_linear_fm_t5

dim

dimensions used in the experiment

cov.param

a matrix with coverages for the prediction regions produced by the parametric method

cov.naive

a matrix with coverages for the prediction regions produced by naive linear regression method

cov.vfcp

na matrix with coverages for the prediction regions produced by VFCP

cov.star

a matrix with coverages for the prediction regions produced by cross validation with the errors

cov.cv5

a matrix with coverages for the prediction regions produced by cross-validation with 5 splits

cov.efcp

a matrix with coverages for the prediction regions produced by efcp