Learn R Programming

ConformalSmallest (version 1.0)

ridge_linear_len100_t5: Outcomes of an example for tuning-free conformal prediction with ridge regression.

Description

A dataset containing the experiment results used in the vignettes.

Usage

ridge_linear_len100_t5

Arguments

Format

A list with 6 elements: len.param_linear_fm_t5, len.naive_linear_fm_t5, len.vfcp_linear_fm_t5, len.star_linear_fm_t5, len.cv5_linear_fm_t5, len.efcp_linear_fm_t5

len.param

a matrix with widths for the prediction regions produced by the parametric method

len.naive

a matrix with widths for the prediction regions produced by naive linear regression method

len.vfcp

na matrix with widths for the prediction regions produced by VFCP

len.star

a matrix with widths for the prediction regions produced by cross validation with the errors

len.cv5

a matrix with widths for the prediction regions produced by cross-validation with 5 splits

len.efcp

a matrix with widths for the prediction regions produced by efcp