A dataset containing the experiment results used in the vignettes.
ridge_linear_len100_t5A list with 6 elements: len.param_linear_fm_t5, len.naive_linear_fm_t5, len.vfcp_linear_fm_t5, len.star_linear_fm_t5, len.cv5_linear_fm_t5, len.efcp_linear_fm_t5
a matrix with widths for the prediction regions produced by the parametric method
a matrix with widths for the prediction regions produced by naive linear regression method
na matrix with widths for the prediction regions produced by VFCP
a matrix with widths for the prediction regions produced by cross validation with the errors
a matrix with widths for the prediction regions produced by cross-validation with 5 splits
a matrix with widths for the prediction regions produced by efcp